/**********************************************************
 *
 * FIGURES.DO
 *
 **********************************************************/

cap log close
cap log using "..\output\figures.log", replace text

**********************************************************
* PRELIMINARIES
**********************************************************
version 10
version
clear
set memory 600m
set matsize 6000
set more off
adopath + ado
adopath + ..\external
tempfile temp

set seed 04271975
set sortseed 04271975

* load input parameters & scalars
loadglob using "input_param.txt"
loadglob using "..\output\intermediate\scalars.txt"
macro list

* create temp file with ideal points
insheet using ..\output\intermediate\idealpoints_0.csv, clear
sort dindex
save `temp', replace
use ..\external\BiasMeasures_clean, clear
sort dindex
merge dindex using `temp', uniqusing nokeep keep(ideal)
tab _merge
drop _merge
sort dindex
save `temp', replace

**********************************************************
* FIGURE: NEWSPAPER-SPECIFIC REP COEFFICIENTS
**********************************************************
use ..\external\demand_clean, clear
sort dindex
quietly vallist dindex, local(dindexlist)
foreach D in `dindexlist' {
	quietly gen zdindex`D'_rep = (dindex==`D')*rep
}
quietly areg logit zdindex19_rep-zdindex1574_rep, absorb(nzip_market_dindex) cluster(dindex)
gen coeff = .
foreach D in `dindexlist' {
	quietly replace coeff = _b[zdindex`D'_rep] if dindex==`D'
}
egen seq = seq(), by(dindex)
scatter coeff slant if numzips>200 & seq==1, msize(small) mlabsize(tiny) xlabel(.4(.05).5) xsc(r(.516)) xtitle( "Slant measure (D <-> R)") ytitle(Coefficient on zip Republican share) scheme(s1mono) legend(off) /*
	*/ || lfit coeff slant if numzips>200 & seq==1, lwidth(vthin) legend(off)
count if numzips>200 & seq==1
pwcorr coeff slant if numzips>200 & seq==1, sig
graph export "..\output\\slant_vs_coeff.eps", as(eps) replace
drop seq coeff zdindex*

**********************************************************
* FIGURE: DAILYSHARE BY NP QUARTILES & ZIP DECILES
**********************************************************

use ..\external\demand_clean, clear
drop if dailyshare==0
gen decile = _n if _n<=10
foreach Q of numlist 1/4 {
	areg logit zdec2-zdec10 if npquart==(`Q'-1) [w=zip_hshd], absorb(nzip_market_dindex) cluster(dindex)
	local cons = _b[_cons]
	matrix coeff = (0\e(b)')
	svmat coeff
	ren coeff1 coeff
	replace coeff = coeff+`cons'
	sum coeff if _n<=10
	local min = r(min)-.005
	local max = r(max)+.005
	display `min'
	display `max'
	if `Q' == 3 {
		twoway bar coeff decile in 1/10, nodraw name(graph`Q') xlabel(1(1)10) yscale(range(`min' `max')) ytitle(Log odds ratio) xtitle(Zipcode decile of Republican contribution share) scheme(s1mono) title(Slant Quartile `Q') fi(inten20) lw(medthick) ylabel(-2.8(.2)-2)
	}
	else {
		twoway bar coeff decile in 1/10, nodraw name(graph`Q') xlabel(1(1)10) yscale(range(`min' `max')) ytitle(Log Odds Ratio) xtitle(Zipcode decile of Republican contribution share) scheme(s1mono) title(Slant Quartile `Q') fi(inten20) lw(medthick) ylabel(#4)
	}
	drop coeff
}

drop decile
graph combine graph1 graph2 graph3 graph4, scheme(s1mono)
graph export "..\output\\npquartiles.eps", as(eps) replace
graph drop graph1 graph2 graph3 graph4

**********************************************************
* FIGURE: SLANT ON PCTREP
**********************************************************
use ..\external\BiasMeasures_clean, clear
scatter pred_rep_2005 pctrep_2004, msymbol(o) xlabel(.3(.1).8) xtitle(Market Percent Republican) ylabel(.35(.05).55) ytitle(Slant) scheme(s1mono) msize(small) || lfit pred_rep_2005 pctrep_2004, legend(order(2))
graph export "..\output\\slantonpctrep.eps", as(eps) replace

**********************************************************
* FIGURE: GROUP SLANT ON SLANT (UNADJUSTED)
**********************************************************
use ..\external\BiasMeasures_clean, clear
pwcorr group_pred_rep_2005 pred_rep_2005, sig
reg group_pred_rep_2005 pred_rep_2005
predict grouphat
drop if group_pred_rep_2005==.
scatter group_pred_rep_2005 grouphat pred_rep_2005, ylab(.38(.04).54) msymbol(o i) connect (i l) ytitle(Average slant of other papers with same owner) xlab(.35(.05).55) xtitle(Slant index) legend(off) scheme(s1mono) msize(small)
graph export "..\output\\slantongroup.eps", as(eps) replace
drop grouphat

************************************************************
* FIGURE: GROUP SLANT ON SLANT (PARTIALED BY STATE)
************************************************************
use ..\external\BiasMeasures_clean, clear
pwcorr group_estate_pred_rep_2005 estate_pred_rep_2005, sig
reg group_estate_pred_rep_2005 estate_pred_rep_2005
predict grouphat
drop if group_pred_rep_2005==.
scatter group_estate_pred_rep_2005 grouphat estate_pred_rep_2005, msymbol(o i) connect (i l) ytitle(Average slant of other papers with same owner - residual) xtitle(Slant index - residual) legend(off) scheme(s1mono) msize(small) ylab(-.08(.02).08) xlab(-.1(.05).05)

graph export "..\output\\slantongroup_partialed.eps", as(eps) replace
drop grouphat

***************************************************************
* FIGURE: CONTRIBUTIONS (EXECUTIVES / CORPORATIONS)
***************************************************************
use ..\external\BiasMeasures_clean, clear

* merge in displaynames
sort gindex
merge gindex using "..\external\displaynames_gindex.dta"
drop if _merge==2
drop _merge
sort dindex
merge dindex using "..\external\displaynames_singlepaper.dta", update
drop if _merge==2
drop _merge
egen groupmean = mean(group_pred_rep_2005), by(gindex)
replace groupmean = pred_rep_2005 if gindex==.
egen seq = seq(), by(gindex)
gen useleft = (seq==1 & groupmean != . & groupdisplayname != "Consolidated")
replace useleft = 1 if gindex==. & groupmean != . & groupdisplayname != "Daily Oklahoman" & groupdisplayname != "Waterbury Republican-American" & groupdisplayname != "Findlay Courier"
gen useright = (gindex==. & groupmean != . & (groupdisplayname == "Daily Oklahoman" | groupdisplayname == "Waterbury Republican-American" | groupdisplayname == "Findlay Courier"))
gen usebotleft = (seq==1 & groupmean != . & groupdisplayname == "Consolidated")

#delimit ;
scatter groupmean repfrac_contrib if useleft & gindex!=. & repfrac_contrib != ., 
	ytitle(Slant index, size(small)) xtitle(Share of contributions to Republicans, size(small))
	scheme(s1mono) msymbol(O) mcolor(gs8) msize(small) mlabel(groupdisplayname) mlabsize(tiny)
	xlabel(0(.2)1,labsize(small)) ylabel(.4(.05).5,labsize(small)) xsc(r(1.151))

|| scatter groupmean repfrac_contrib if usebotleft & gindex!=. & repfrac_contrib != ., 
	msymbol(O) mcolor(gs8) msize(small) mlabel(groupdisplayname) mlabsize(tiny) mlabp(4)

|| scatter groupmean repfrac_contrib if useleft & gindex==. & repfrac_contrib != ., 
	msymbol(+) mcolor(black) msize(small) mlabel(groupdisplayname) mlabsize(tiny)

|| scatter groupmean repfrac_contrib if useright & gindex==. & repfrac_contrib != ., 
	msymbol(+) mcolor(black) msize(small) mlabel(groupdisplayname) mlabsize(tiny) mlabp(9)

|| scatter groupmean repfrac_pubint if useleft & repfrac_pubint != ., 
	msymbol(Dh) mcolor(black) msize(small) mlabel(groupdisplayname) mlabsize(tiny) 

	legend(order(1 3 5) label(1 "Newspaper Group Executives") label(3 "Independent Newspaper Executives") 
	label(5 "Newspaper Group Corporate Contributions") 
	cols(1) size(vsmall));
#delimit cr
graph export "..\output\\contributions.eps", as(eps) replace

* correlations
pwcorr groupmean repfrac_contrib if (useleft | useright | usebotleft) & gindex!=., sig
pwcorr groupmean repfrac_contrib if (useleft | useright | usebotleft) & gindex==., sig
pwcorr groupmean repfrac_pubint if (useleft | useright | usebotleft), sig
drop use* seq

***************************************************************
* APPENDIX FIGURE: MONDO TIMES
***************************************************************
use ..\external\BiasMeasures if papername~="Chicago Defender", clear
sort dindex
merge dindex using ..\external\displaynames_dindex
drop _merge

* edit mondoclockpos
replace mondoclockpos = 9 if displayname == "Washington Times"
replace mondoclockpos = 9 if displayname == "Salt Lake Deseret News"
replace mondoclockpos = 1 if displayname == "San Francisco Chronicle"
replace mondoclockpos = 6 if displayname == "Philadelphia Inquirer"
replace mondoclockpos = 5 if displayname == "New York Times"
replace mondoclockpos = 7 if displayname == "Boston Globe"
replace mondoclockpos = 6 if displayname == "Los Angeles Times"
replace mondoclockpos = 6 if displayname == "Washington Post"
replace mondoclockpos = 6 if displayname == "Newark Star-Ledger"
replace mondoclockpos = 12 if displayname == "St. Petersburg Times"
replace mondoclockpos = 6 if displayname == "Memphis Commercial Appeal"
replace mondoclockpos = 2 if displayname == "Milwaukee Journal Sentinel"

scatter pred_rep_2005 polrating if polvotes>1 & totcount_2005> 25000, msymbol(o i) connect (i l)  mlabel(displayname) mlabsize(tiny) msize(small) /*
		*/ ysize(3.7) xsize(4) ylab(.4(.05).5) xlab(2(1)4) ytitle(Slant index) xtitle(Mondo Times conservativeness rating) scheme(s1mono) legend(off) mlabvposition(mondoclockpos) /*
		*/ || lfit pred_rep_2005 polrating if polvotes>1 & totcount_2005> 25000, lwidth(vthin)
graph export "..\output\\slantvsmondo.eps", as(eps) replace
pwcorr pred_rep_2005 polrating if polvotes>1 & totcount_2005> 25000, sig

cap log close




