%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% IDEALPOINTS.M: Compute ideal slant for each newspaper, looping over main specification
%   and robustness checks.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

global EPSILON
addpath('..\external\')

tic

% load parameters
nrobust = loadparam('nrobust','input_param.txt');

for mm = 0:nrobust

    display(['Calculating Ideal Points and Derivatives for Model ' num2str(mm)])
    
    % import data, parameter vector, and standard deviation of slant from Stata output
    imp=importdata(['..\output\intermediate\demand_data_' num2str(mm) '.csv']);
    data=imp.data;
    colheaders=imp.colheaders;
    imp=importdata(['..\output\intermediate\demand_b_' num2str(mm) '.csv']);
    b = imp.data';
    names = imp.colheaders;
    sdslant = loadparam(['sdslant_' num2str(mm)],'..\output\intermediate\scalars.txt');
    
    % check that the variables in the data matrix are the correct ones
    if ~strcmp(colheaders(1),'dindex') | ~strcmp(colheaders(2),'slantmeas') | ...
            ~strcmp(colheaders(3),'logit') |~strcmp(colheaders(4),'rep') | ...
            ~strcmp(colheaders(5),'hshd_weighted')
        error('Incorrect variable names in input to idealpoints.m')
    end

    % check that the variables in the parameter vector are the correct ones
    if ~strcmp(names(1),'alpha') | ~strcmp(names(2),'beta') | ~strcmp(names(3),'gamma')
        error('Incorrect variable names in input to idealpoints.m')
    end

    % compute ideal points
    [ideal pctloss param] = calcideal(data,b,sdslant);

    % write idealpoints.csv
    fid = fopen(['..\output\intermediate\idealpoints_' num2str(mm) '.csv'], 'w');
    fprintf(fid,'dindex,ideal,dideal_dalpha,dideal_dbeta,dideal_dgamma\n');
    fclose(fid);
    dlmwrite(['..\output\intermediate\idealpoints_' num2str(mm) '.csv'],ideal,'-append');

    % write pctloss.csv
    fid = fopen(['..\output\intermediate\pctloss_' num2str(mm) '.csv'], 'w');
    fprintf(fid,'dindex,pctloss,dpctloss_dalpha,dpctloss_dbeta,dpctloss_dgamma\n');
    fclose(fid);
    dlmwrite(['..\output\intermediate\pctloss_' num2str(mm) '.csv'],pctloss,'-append');

    % write paramdraws.csv
    fid = fopen(['..\output\intermediate\paramdraws_' num2str(mm) '.csv'], 'w');
    fprintf(fid,'draw,alpha,beta,gamma\n');
    fclose(fid);
    dlmwrite(['..\output\intermediate\paramdraws_' num2str(mm) '.csv'],param,'-append');

end

toc





