/**********************************************************
 *
 * MAINDEMAND.DO: Run main demand model & export data & parameters
 *	for use in the matlab script idealpoints.m
 *
 **********************************************************/

cap log close
cap log using "..\output\mainmodels.log", text replace

**********************************************************
* PRELIMINARIES
**********************************************************
version 10
version
clear
set memory 600m
set matsize 6000
set more off
adopath + ado
adopath + ..\external
tempfile temp

set seed 04271975
set sortseed 04271975

* load input parameters & scalars
loadglob using "input_param.txt"
macro list

**********************************************************
* RUN MODELS & EXPORT PARAMETERS FOR MATLAB
**********************************************************
foreach M of numlist 0/$nrobust {

	di _newline(4)
	di "Model: `M'"
	di "Demand Sample: ${dsample_`M'}"
	di "Supply Sample: ${ssample_`M'}"
	di "Slant Variable: ${slant_`M'}"
	di "Demand Slant Variable: ${dslant_`M'}"
	di "Rep_Slant Variable: ${rep_slant_`M'}"
	di "Zipcode Weight: ${zipweight_`M'}"
	di _newline

	* demand
	use ..\external\demand_clean, clear
	drop if dailyshare==0
	cap keep if ${dsample_`M'}
	xtivreg2 logit (${rep_slant_`M'}=rep_pctrep) rep rep2 $zipdemos $waldfogel, i(nzip_market_dindex) cluster(dindex) fe first
	estimates save ..\output\intermediate\demand_`M'.ster, replace
	nlcom (alpha:-_b[rep]/_b[rep_slant]) (beta:-2*_b[rep2]/_b[rep_slant]) (gamma:_b[rep_slant]/(2*(-2*_b[rep2]/_b[rep_slant]))), post
	matrix COV = e(V)
	matrix B = e(b)

	* save data, parameters, and covariance matrix for use in Matlab
	save `temp', replace
	gen slantmeas = ${dslant_`M'}
	gen hshd_weighted = zip_hshd * ${zipweight_`M'}
	outsheet dindex slantmeas logit rep hshd_weighted using ..\output\intermediate\demand_data_`M'.csv, comma replace
	clear
	svmat B, names(col)
	outsheet using ..\output\intermediate\demand_b_`M'.csv, comma replace
	clear
	svmat COV, names(col)
	outsheet using ..\output\intermediate\demand_cov_`M'.csv, comma replace nonames

	* supply
	use ..\external\BiasMeasures_clean, clear
	cap keep if ${ssample_`M'}
	myrereg ${slant_`M'} pctrep_2004 zstate*, panel(gindex_nomiss)
	estimates save ..\output\intermediate\supply_`M'.ster, replace



}

cap log close

