REM ****************************************************
REM * make.bat: double-click to run all scripts
REM *
REM * The following must be on the Windows path:
REM * - Stata
REM * - Matlab
REM *
REM * Running this script also requires having a
REM * Windows environment variable called STATAEXE
REM * defined which contains the name of the stata
REM * executable on the machine. E.g.
REM *	STATAEXE=wmpstata
REM *	STATAEXE=wsestata
REM *
REM ****************************************************

SET LOG=..\output\make.log

REM LOG START
ECHO make.bat started	>%LOG%
ECHO %DATE%		>>%LOG%
ECHO %TIME%		>>%LOG%

REM GET_EXTERNALS
CALL get_externals	>>%LOG% 2>&1

REM PRECLEAN
%STATAEXE% /e do preclean.DO

REM PRELIMINARY ANALYSIS
%STATAEXE% /e do scalars.DO
%STATAEXE% /e do mainmodels.DO
matlab -r "idealpoints; exit" -logfile idealpoints.log -nosplash -wait

REM MAIN ANALYSIS
%STATAEXE% /e do text.DO
%STATAEXE% /e do tables.DO
%STATAEXE% /e do figures.DO

COPY %LOG%+preclean.log+scalars.log+mainmodels.log+idealpoints.log+text.log+tables.log+figures.log %LOG%
DEL preclean.log scalars.log mainmodels.log idealpoints.log text.log tables.log figures.log

REM LOG END
ECHO make.bat completed	>>%LOG%
ECHO %DATE%		>>%LOG%
ECHO %TIME%		>>%LOG%

PAUSE

