**********************************************************
*
* PRECLEAN
*
**********************************************************

cap log close
cap log using "..\output\preclean.log", replace text

**********************************************************
* PRELIMINARIES
**********************************************************
version 10
version
clear
set memory 600m
set matsize 6000
set more off
adopath + ado
adopath + ..\external

set seed 04271975
set sortseed 04271975

* load input parameters & scalars
loadglob using "input_param.txt"
macro list

**********************************************************
* SUPPLY DATA
**********************************************************
use "..\external\BiasMeasures.dta", clear

drop if pred_rep_2005==.
gen lincpc00 = log(incpc00)

* throw out outlier
sum pred_rep_2005 if papername!="Chicago Defender", det
sum pred_rep_2005 if papername=="Chicago Defender"
drop if papername=="Chicago Defender"

* drop national papers *
drop if papername=="USA TODAY" | papername=="The New York Times" | papername=="The Wall Street Journal" | papername=="The Christian Science Monitor"

gen lemployees = log(employees)
gen polrating_int = round(polrating)
gen lpop00 = log(pop00)
gen ldensity00 = log(density00)

* standardized slant measures
sum pred_rep_2005
local sd_2005 = r(sd)
local mean_2005 = r(mean)
gen spred_rep_2005 = pred_rep_2005

gen gindex_nomiss = gindex
replace gindex_nomiss = dindex*10000 if gindex_nomiss==.

quietly tab regce, gen(zreg)
quietly tab divce, gen(zdiv)
quietly tab state, gen(zstate)
quietly tab gindex if gindex!=., gen(zgindex)
drop zreg1 zdiv1 zstate1 zgindex1

* DEFINE (PARTIALED) GROUP MEAN SLANT
* no controls
egen sum = sum(pred_rep_2005), by(gindex)
egen count = count(pred_rep_2005), by(gindex)
gen group_pred_rep_2005 = (sum-pred_rep_2005) / (count-1)
drop sum count
replace group_pred_rep_2005=. if gindex==.

* MERGE IN INCUMBENT GOVERNOR
sort state
merge state using ..\external\govparty_dec_2005.dta
tab _merge
drop _merge
gen govrep = 1 if govparty_dec_2005=="Republican"
replace govrep = 0 if govparty_dec_2005=="Democrat"
drop govparty_dec_2005

* CREATE NORMALIZED ADA MEASURE
gen pred_ada_2005_norm = pred_ada_2005/100

* partialed
genpartialed "e_pred_rep_2005" "group_e_pred_rep_2005" "pred_rep_2005" "pctrep_2004"
genpartialed "ediv_pred_rep_2005" "group_ediv_pred_rep_2005" "pred_rep_2005" "pctrep_2004 zdiv2-zdiv9"
genpartialed "estate_pred_rep_2005" "group_estate_pred_rep_2005" "pred_rep_2005" "pctrep_2004 zstate*"
genpartialed "edemo_pred_rep_2005" "group_edemo_pred_rep_2005" "pred_rep_2005" "pctrep_2004 $demos"

sort dindex
save "..\external\BiasMeasures_clean.dta", replace

**********************************************************
* DEMAND DATA
**********************************************************
use "..\external\demand.dta", clear

* drop if rep is missing or if there are fewer than 20 contributions
*** note that 20 contribution limit is change from previous versions ***
drop if rep==.
drop if rep_count+dem_count<20

* drop obs where dailyshare is missing (all of these have denominator missing)
drop if dailyshare==.

* drop cases with only one obs within a zip_market_dindex
egen sd = sd(dailyshare), by(zip_market_dindex)
drop if sd==.
drop sd

* drop obs where zipdemos are missing
egen nmissing = rmiss($zipdemos $waldfogel)
drop if nmissing>0
drop nmissing

* drop Chicago Defender
drop if papername=="Chicago Defender"

* merge in ad revenue variables (profit weights)
sort dindex zipcode
merge dindex zipcode using "..\external\costrev_byzipcode.dta"
tab _merge
drop if _merge==2
drop _merge

* tag obs where only one paper in zipcode
egen numzips = count(dailyshare), by(dindex)

* quartile and decile dummies
quietly tab zipdec, g(zdec)

gen nzipcode = real(zipcode)

* merge in predicted NOMINATE score & normalized predicted ADA score
sort dindex
merge dindex using ..\external\BiasMeasures_clean.dta, uniqusing nokeep keep(pred_cs1_2005 pred_ada_2005_norm)
tab _merge
drop _merge

* CREATE REP_SLANT VARIABLES FOR ROBUSTNESS CHECKS
gen rep_slantsm = rep*pred_repsm_2005
gen rep_slantada_norm = rep*pred_ada_2005_norm
gen rep_slantcs1 = rep*pred_cs1_2005

save "..\external\demand_clean.dta", replace

**********************************************************
* OLD DEMAND SAMPLE DATA (NOT DROPPING <20 CONTRIBS)
**********************************************************
use "..\external\demand.dta", clear

* drop if rep is missing or if there are fewer than 20 contributions
*** note that 20 contribution limit is change from previous versions ***
drop if rep==.

* drop obs where dailyshare is missing (all of these have denominator missing)
drop if dailyshare==.

* drop cases with only one obs within a zip_market_dindex
egen sd = sd(dailyshare), by(zip_market_dindex)
drop if sd==.
drop sd

* drop obs where zipdemos are missing
egen nmissing = rmiss($zipdemos $waldfogel)
drop if nmissing>0
drop nmissing

* drop Chicago Defender
drop if papername=="Chicago Defender"

save ..\external\demand_oldsample, replace

***************************************
* ZIPCODE FILE TO VERIFY FEC VARIABLE *
***************************************

use "..\external\zip_contrib.dta", clear
rename indivzip ZipCode
destring ZipCode, replace force
sort ZipCode
merge ZipCode using "..\external\Reg_By_Zip.dta"
tab _merge
keep if _merge==3
drop _merge
drop if rep_count+dem_count<20
gen rep_reg_share = RepZip/(RepZip+DemZip)
keep ZipCode rep_count_share rep_reg_share
save "..\external\zip_contrib_clean.dta", replace

cap log close
