**********************************************************
*
* SCALARS.DO: Write scalars (mostly means and variances)
*	that depend on the data and will be used as
*	inputs to the analysis.
*
**********************************************************

version 10

cap log close
cap log using "..\output\scalars.log", replace text

**********************************************************
* PRELIMINARIES
**********************************************************
version 10
version
clear
set memory 600m
set matsize 6000
set more off
adopath + ado
adopath + ..\external

set seed 04271975
set sortseed 04271975

* load input parameters & scalars
loadglob using "input_param.txt"
macro list

* OPEN OUTPUT FILE
cap file close OUT
file open OUT using ..\output\intermediate\scalars.txt, write text replace


**********************************************************
* CONGRESS DATA
**********************************************************
use "..\external\BiasMeasures_people.dta", clear

* CORRELATION WITH TRUE IDEOLOGY
corr repshare_109 pred_repall_2005
file write OUT "pwcorrtrue `r(rho)'" _n

**********************************************************
* SUPPLY DATA
**********************************************************
use ..\external\BiasMeasures_clean.dta, clear

* VARIANCE COMPONENTS
sum pred_rep_2005
file write OUT "sdslant `r(sd)'" _n

sum pctrep_2004
file write OUT "sdpctrep `r(sd)'" _n

sdcalc "pred_rep_2005 pctrep_2004" "zdiv*"
file write OUT "sdslantdiv `r(pred_rep_2005)'" _n
file write OUT "sdpctrepdiv `r(pctrep_2004)'" _n

sdcalc "pred_rep_2005 pctrep_2004" "zstate*"
file write OUT "sdslantstate `r(pred_rep_2005)'" _n
file write OUT "sdpctrepstate `r(pctrep_2004)'" _n

sdcalc "pred_rep_2005 pctrep_2004" "zgindex*"
file write OUT "sdslantgindex `r(pred_rep_2005)'" _n
file write OUT "sdpctrepgindex `r(pctrep_2004)'" _n

sdcalc "pred_rep_2005 pctrep_2004" "$demos"
file write OUT "sdslantdemo `r(pred_rep_2005)'" _n
file write OUT "sdpctrepdemo `r(pctrep_2004)'" _n

**********************************************************
* SUPPLY DATA: STRUCTURAL MODEL / ROBUSTNESS CHECKS
**********************************************************
foreach M of numlist 0/$nrobust {
	use ..\external\BiasMeasures_clean.dta, clear
	cap keep if ${ssample_`M'}
	sum ${slant_`M'}
	file write OUT "sdslant_`M' `r(sd)'" _n
	sdcalc "${slant_`M'} pctrep_2004" "zstate*"
	file write OUT "sdslantstate_`M' `r(${slant_`M'})'" _n
	file write OUT "sdpctrepstate_`M' `r(pctrep_2004)'" _n
}

**********************************************************
* SUPPLY DATA: MIN AND MAX SLANT IN EACH SAMPLE
**********************************************************
foreach M of numlist 0/$nrobust {
	use ..\external\BiasMeasures_clean.dta, clear
	cap keep if ${ssample_`M'}
	sum ${slant_`M'}
	file write OUT "minslant_`M' `r(min)'" _n
	file write OUT "maxslant_`M' `r(max)'" _n
}

* CLOSE OUTPUT FILE
file close OUT

cap log close
