/**********************************************************
 *
 * TABLES.DO
 *		  	
 **********************************************************/

cap log close
cap log using "..\output\tables.log", replace text
set linesize 255

**********************************************************
* PRELIMINARIES
**********************************************************
version 10
version
clear
set memory 600m
set matsize 6000
set more off
adopath + ado
adopath + ..\external

set seed 04271975
set sortseed 04271975

* load input parameters & scalars
loadglob using "input_param.txt"
loadglob using "..\output\intermediate\scalars.txt"
macro list

**********************************************************
* TABLE: WORDS
**********************************************************
use "..\external\2005_Wordlist", clear
gen rep = naiverat>1
gsort -rep words -chi2
outsheet originalphrase rep words using "..\output\words2005.txt", replace

**********************************************************
* TABLE: DEMAND
**********************************************************
use ..\external\demand_clean, clear

* OLS
areg logit rep_slant rep rep2, absorb(nzip_market_dindex) cluster(dindex)

* OLS + demos + waldfogel
areg logit rep_slant rep rep2 $zipdemos $waldfogel, absorb(nzip_market_dindex) cluster(dindex)

* zipcode FFX
xi: areg logit rep_slant $waldfogel i.nzip_market_dindex, absorb(zipcode) cluster(dindex)

* reduced-form second stage + demos + waldfogel
areg logit rep_pctrep rep rep2 $zipdemos $waldfogel, absorb(nzip_market_dindex) cluster(dindex)

* IV, + demos & waldfogel
xtivreg2 logit (rep_slant=rep_pctrep) rep rep2 $zipdemos $waldfogel, i(nzip_market_dindex) cluster(dindex) fe first

* note that correct numobs for final specification is numobs reported by xtivreg2 PLUS the number of singleton observations dropped
* (replay to confirm that we have the same specification as in mainmodels.do)
estimates use ..\output\intermediate\demand_0.ster
estimates replay

**********************************************************
* TABLE: DETERMINANTS
**********************************************************
use ..\external\BiasMeasures_clean, clear

* ols
reg pred_rep_2005 pctrep_2004

* ownership fixed effects
areg pred_rep_2005 pctrep_2004, absorb(gindex_nomiss)

* church IV
ivreg pred_rep_2005 (pctrep_2004=churchmonthly), first

* random effects (w/ state fixed effects)--main specification
* myrereg ${slant_`M'} pctrep_2004 zstate*, panel(gindex_nomiss)
estimates use ..\output\intermediate\supply_0.ster
estimates replay

* random effects (w/ state fixed effects) using xtmixed to double check no problem with myrereg
xtmixed pred_rep_2005 pctrep_2004 zstate*|| gindex_nomiss:, mle

* random effects (w/state fixed effects) using xtreg to double-check order of magnitude for standard errors
bootstrap e(sigma_u) e(sigma_e), reps(100) seed(120879) cluster(gindex_nomiss): xtreg pred_rep_2005 pctrep_2004 zstate*, i(gindex_nomiss) re

**********************************************************
* TABLE: STRUCTURAL MODEL &  APPENDIX TABLE: ROBUSTNESS
**********************************************************
* note M==0 is main specification; M>0 are robustness checks
foreach M of numlist 0/$nrobust {

	di _newline(4)
	di "Model: `M'"
	di "Demand Sample: ${dsample_`M'}"
	di "Supply Sample: ${ssample_`M'}"
	di "Slant Variable: ${slant_`M'}"
	di "Demand Slant Variable: ${dslant_`M'}"
	di "Rep_Slant Variable: ${rep_slant_`M'}"
	di "Zipcode Weight: ${zipweight_`M'}"
	di _newline

	* AVERAGE AND IDEAL SLANT
	tempfile temp
	insheet using "..\output\intermediate\idealpoints_`M'.csv", clear
	sort dindex
	merge dindex using "..\external\BiasMeasures_clean.dta", uniqusing nokeep keep(${slant_`M'})
	quietly drop _merge
	mean ${slant_`M'}
	local mean_slant = _b[${slant_`M'}]
	mean ideal dideal_dalpha dideal_dbeta dideal_dgamma
	local mean_ideal = _b[ideal]	
	local deriv_alpha = _b[dideal_dalpha]
	local deriv_beta = _b[dideal_dbeta]	
	local deriv_gamma = _b[dideal_dgamma]
	estimates use ..\output\intermediate\demand_`M'.ster
	nlcom (alpha:-_b[rep]/_b[rep_slant]) (beta:-2*_b[rep2]/_b[rep_slant]) (gamma:_b[rep_slant]/(2*(-2*_b[rep2]/_b[rep_slant]))), post
	estimates store param
	local alpha = _b[alpha]
	local beta = _b[beta]
	local gamma = _b[gamma]
	lincom `mean_ideal' + `deriv_alpha' * (_b[alpha]-`alpha') + `deriv_beta'* (_b[beta]-`beta') + `deriv_gamma' * (_b[gamma]-`gamma')
	test `mean_ideal' + `deriv_alpha' * (_b[alpha]-`alpha') + `deriv_beta'* (_b[beta]-`beta') + `deriv_gamma' * (_b[gamma]-`gamma') = `mean_slant'

	* PERCENT LOSS FROM 1SD DEVIATION:
	insheet using "..\output\intermediate\pctloss_`M'.csv", clear
	mean pctloss dpctloss_dalpha dpctloss_dbeta dpctloss_dgamma
	local mean_pctloss = _b[pctloss]	
	local deriv_alpha = _b[dpctloss_dalpha]
	local deriv_beta = _b[dpctloss_dbeta]
	local deriv_gamma = _b[dpctloss_dgamma]
	estimates restore param
	lincom `mean_pctloss' + `deriv_alpha' * (_b[alpha]-`alpha') + `deriv_beta'* (_b[beta]-`beta') + `deriv_gamma' * (_b[gamma]-`gamma')

	* VARIANCE SHARES
	estimates use ..\output\intermediate\supply_`M'.ster
	
	* handle numerical problem in nlcom when estiamted owner variance is very small
	cap nlcom exp(_b[/lns_u])^2/${sdslantstate_`M'}^2
	if _rc==0 {
		nlcom (consshare: _b[pctrep_2004]^2*${sdpctrepstate_`M'}^2/${sdslantstate_`M'}^2) (ownshare: exp(_b[/lns_u])^2/${sdslantstate_`M'}^2), post
		test _b[consshare]=_b[ownshare]
	}
	else {
		nlcom (consshare: _b[pctrep_2004]^2*${sdpctrepstate_`M'}^2/${sdslantstate_`M'}^2)
		quietly lincom _b[/lns_u]
		di "Point Estimate for Owner Share: " exp(_b[/lns_u])^2/${sdslantstate_`M'}^2
		di "Standard Error for Owner Share:" 2*exp(_b[/lns_u])^2/${sdslantstate_`M'}^2 * r(se)
	}
}

**********************************************************   
* APPENDIX TABLE: MEASURING OWNER IDEOLOGY WITH CONTRIBUTIONS
**********************************************************

use ..\external\BiasMeasures_clean, clear

* newspaper group executives
areg pred_rep_2005 repfrac_contrib pctrep_2004 if gindex!=., absorb(state) cluster(gindex)
* independent newspaper executives
areg pred_rep_2005 repfrac_contrib pctrep_2004 if gindex==., absorb(state)
* newspaper group corporate contributions
areg pred_rep_2005 repfrac_pubint pctrep_2004, absorb(state) cluster(gindex)

**********************************************************   
* APPENDIX TABLE: INCUMBENT POLITICIANS
**********************************************************
use ..\external\BiasMeasures_clean, clear
reg pred_rep_2005 pctrep_2004 govrep, cluster(state)
reg pred_rep_2005 pctrep_2004 houserep

**********************************************************   
* APPENDIX TABLE: STEPPING FROM OLD TO NEW DEMAND RESULTS
**********************************************************
* note that pctloss in the linear models below is simply (gamma)*$sdslant/avgdailyshare
* pctloss for the final (logit) model must be computed numerically; see results above

use ..\external\demand_oldsample, clear

* compute average dailyshare
sum dailyshare [w=zip_hshd] if np_market==zip_market
local avgdailyshare = r(mean)

* generate variables for measurement error correction
gen reptemp = rep
sum rep if rep>0 & rep<1
replace reptemp = r(min) if reptemp==0
replace reptemp = r(max) if reptemp==1
sum reptemp
gen vmeas = r(mean)*(1-r(mean))/(dem_count+rep_count)
erepgen "$zipdemos $waldfogel"

* results from November 2006 NBER working paper version
xtivreg2 dailyshare (Erep_slant=Erep_pctrep) Erep Erep2 $zipdemos $waldfogel, i(nzip_market_dindex) cluster(dindex) fe
di "alpha = " -_b[Erep]/_b[Erep_slant]
di "beta = " -2*_b[Erep2]/_b[Erep_slant]
di "gamma = " _b[Erep_slant]/(2*(-2*_b[Erep2]/_b[Erep_slant]))
di "percent loss = " (_b[Erep_slant]/(2*(-2*_b[Erep2]/_b[Erep_slant])))*$sdslant^2/`avgdailyshare'

* replace measurement error correction with condition on # contributions
xtivreg2 dailyshare (rep_slant=rep_pctrep) rep rep2 $zipdemos $waldfogel if (rep_count+dem_count>=20), i(nzip_market_dindex) cluster(dindex) fe
di "alpha = " -_b[rep]/_b[rep_slant]
di "beta = " -2*_b[rep2]/_b[rep_slant]
di "gamma = " _b[rep_slant]/(2*(-2*_b[rep2]/_b[rep_slant]))
di "percent loss = " (_b[rep_slant]/(2*(-2*_b[rep2]/_b[rep_slant])))*$sdslant^2/`avgdailyshare'

* exclude observations with dailyshare==0
xtivreg2 dailyshare (rep_slant=rep_pctrep) rep rep2 $zipdemos $waldfogel if (rep_count+dem_count>=20) & dailyshare>0, i(nzip_market_dindex) cluster(dindex) fe
di "alpha = " -_b[rep]/_b[rep_slant]
di "beta = " -2*_b[rep2]/_b[rep_slant]
di "gamma = " _b[rep_slant]/(2*(-2*_b[rep2]/_b[rep_slant]))
di "percent loss = " (_b[rep_slant]/(2*(-2*_b[rep2]/_b[rep_slant])))*$sdslant^2/`avgdailyshare'

* use logit dependent variable (preferred estimates in published version)
xtivreg2 logit (rep_slant=rep_pctrep) rep rep2 $zipdemos $waldfogel if (rep_count+dem_count>=20) & dailyshare>0, i(nzip_market_dindex) cluster(dindex) fe
di "alpha = " -_b[rep]/_b[rep_slant]
di "beta = " -2*_b[rep2]/_b[rep_slant]
di "gamma = " _b[rep_slant]/(2*(-2*_b[rep2]/_b[rep_slant]))


cap log close




