/**********************************************************
 *
 * TEXT.DO
 *		  	
 **********************************************************/

cap log close
cap log using "..\output\text.log", replace text

**********************************************************
* PRELIMINARIES
**********************************************************
version 10
version
clear
set memory 600m
set matsize 6000
set more off
adopath + ado
adopath + ..\external
set seed 04271975
set sortseed 04271975
tempfile temp 

* load input parameters & scalars
loadglob using "input_param.txt"
loadglob using "..\output\intermediate\scalars.txt"
macro list

**********************************************************
* SECTION {data}
**********************************************************

use ..\external\dailies2001_clean.dta, clear
sum dailycirc
local totaldailycirc = r(mean) * r(N)

use ..\external\BiasMeasures, clear
sum dailycirc if papername~="Chicago Defender"
local sampledailycirc = r(mean) * r(N)
local pctdailycirc = `sampledailycirc'/`totaldailycirc'
local nobs = r(N)
sum pred_rep_2005 if papername=="Chicago Defender"
local defendslant = r(mean)
sum pred_rep_2005 if papername~="Chicago Defender"
local defender = abs((`defendslant' - r(mean))/r(sd))

use ..\external\BiasMeasures_clean, clear
sum dailycirc
local nobs_sample = r(N)

use ..\external\demand_clean.dta, clear
unique dindex if dailyshare>0
local nobsdemand = r(sum)

use ..\external\zip_contrib_clean.dta, clear
correlate rep_count_share rep_reg_share
local validityfec = r(rho)

use ..\external\demand_clean.dta, clear
egen totcirc = sum(dailycirc), by(dindex)
egen mktcirc = sum(dailycirc * (zip_market==np_market)), by(dindex)
gen shareinmkt = mktcirc/totcirc
egen tag = tag(dindex)
sum shareinmkt if tag==1, det
local shareinmkt = r(p50)

**********************************************************
* SECTION {measure}
**********************************************************

use ..\external\2005_Wordlist.dta, clear
mkmat dcount rcount  if phrase=="death tax" | phrase=="estate tax", matrix(countcrdeathtax) rownames(phrase)

use ..\external\2005_NewsCounts.dta, clear
gen papername = "Washington Post" if dindex==245
replace papername = "Washington Times" if dindex==246
sort papername phrase
keep if papername!="" & (phrase=="death tax" | phrase=="estate tax")
drop dindex
replace phrase = "deathtax" if phrase=="death tax"
replace phrase = "estatetax" if phrase=="estate tax"
reshape wide hitcount, i(papername) j(phrase) string
gen ratio =  hitcountestatetax/ hitcountdeathtax
mkmat hitcountdeathtax hitcountestatetax ratio, matrix(countdcdeathtax) rownames(papername)

use ..\external\BiasMeasures_clean, clear
sum dailycirc, det
local quartile = r(p25)
sum totcount_2005, det
local totcountmean = r(mean)
sum totcount_2005 if dailycirc<`quartile', det
local totcountqt = r(mean)

use ..\external\BiasMeasures_people.dta, clear
correlate pred_repall_2005 repshare_109
local pwcorrslant = r(rho)

**********************************************************
* SECTION {ident}
**********************************************************

use ..\external\BiasMeasures, clear
gen descrip = papername + " " + city + " " + state
mkmat gindex if gindex==86, matrix(nytexample) rownames(descrip)

use ..\external\BiasMeasures_clean, clear
keep if gindex~=.
egen numingroup = count(pred_rep_2005), by(gindex)
keep if numingroup>1
unique state, by(gindex) gen(temp)
egen numstate = max(temp), by(gindex)
egen seq = seq(), by(gindex)
tab numstate if seq==1
keep if seq==1
gen twostate = numstate>2
sum twostate
local sumstatowner = r(mean)

**********************************************************
* SECTION {additional}
**********************************************************

use ..\external\reporters.dta, clear
gen lnwage = log(incwage)
xi: reg otherstate reporter i.educrec i.age i.year i.race i.sex
local reporterborn = _b[reporter]
xi: reg othermet reporter i.educrec i.age i.year i.race i.sex
local reportermove = _b[reporter]
xi: reg lnwage otherstate i.educrec i.age i.year i.race i.sex if reporter==1&sex==1&race==1&uhrswork>=35&wkswork1>=50
local reporterwage = _b[otherstate]
* for comparison: non-reporters *
xi: reg lnwage otherstate i.educrec i.age i.year i.race i.sex if reporter==0&sex==1&race==1&uhrswork>=35&wkswork1>=50

use ..\external\BiasMeasures_clean, clear
sum pred_wball_2005 pred_rep_2005
reg pred_wball_2005 pctrep_2004
estimates store wb
reg pred_rep_2005 pctrep_2004
estimates store full
suest wb full
test [wb_mean]pctrep_2004=[full_mean]pctrep_2004
estimates store wbfull

**********************************************************
* APPENDIX {searchapp}
**********************************************************

use ..\external\db2005, clear
drop if dindex==9999|dindex==392
tab newslibrary proquest, matcell(pqnlcount)

**********************************************************
* REPORT CALCULATED NUMBERS
**********************************************************

* {pctdailycirc} Share of daily circulation in sample
display `pctdailycirc'

* {nobs} Number of daily newspapers in whole sample
display `nobs'

* {nobssample} Number of daily newspapers used in analysis
display `nobs_sample'

* {shareinmkt} Share of median paper's circulation in primary market
display `shareinmkt'

* {defender} Number of SDs from the mean: Chicago Defender
display `defender'

* {nobsdemand} Number of newspapers in demand data
display `nobsdemand'

* {validityfec} Correlation of donation share with registration share in CA
display `validityfec'

* {countcrdeathtax} Counts of death tax / estate tax by party
matrix list countcrdeathtax

* {countdcdeathtax}
matrix list countdcdeathtax

* {phraseselection}
** PARAMETER

* {phrasenum}
** PARAMETER

* {totcountmean} Average total use of all 1000 phrases
display `totcountmean'

* {totcountqt} Average total use of all 1000 phrases, papers in bottom circ quartile
display `totcountqt'

* {pwcorrslant} Correlation of slant and true ideology in Congress
display `pwcorrslant'
display `pwcorrslant'^2
display 1-`pwcorrslant'^2

* {sumstatowner}
display `sumstatowner'

* {nytexample}
matrix list nytexample

* {quality}
** NBER VERSION

* {ivdemo}
** NBER VERSION

* {changes}
** NBER VERSION

* {ownerdiv}
** NBER VERSION

* {pctrepdiv}
** NBER VERSION

* {ownerchange}
** NBER VERSION

* {reporterborn}
display `reporterborn'

* {reporterwage}
display `reporterwage'

* {reportermove}
display `reportermove'

* {washbureau}
estimates replay wb
estimates replay wbfull
test [wb_mean]pctrep_2004=[full_mean]pctrep_2004

* {numpqnl}
matrix list pqnlcount
display "newslibrary: " pqnlcount[2,1]+pqnlcount[2,2]
display "proquest: " pqnlcount[1,2]+pqnlcount[2,2]
display "overlap: " pqnlcount[2,2]

* {pwcorrnlpq}
** SEE <..\external\searches_build.log> LINES 114-135

cap log close


