/**********************************************************
 *
 * DEMAND_BUILD.DO: Builds demand.dta for BiasMeasures analysis.
 *
 *		  	
 **********************************************************/

**********************************************************
* INPUT FILES
**********************************************************
* zipcode-newspaper level
local zipcirc "..\external\npzipcirczeroes_mkt.dta"

* zipcode-level
local zipcontrib "..\external\zip_contrib.dta"
local zipdemos "..\external\demos_zip.dta"

* newspaper-level
local dailies "..\external\dailies2001_clean.dta"
local npdemos "..\external\demos.dta"
local biasmeas "..\output\BiasMeasures.dta"
local npids "..\external\from_abcid.dta"

**********************************************************
* OUTPUT FILES
**********************************************************
local output "..\output\demand.dta"
tempfile outputabc

tempfile temp tempzip tempnp temppmsa

**********************************************************
* PRELIMINARIES
**********************************************************
clear
set memory 800m
set matsize 100
set more off

* measure to use
local MEASURE "pred_rep_2005"
local TOTCOUNT "totcount_2005"

**********************************************************
* ASSEMBLE ZIPCODE-LEVEL TEMP FILE
**********************************************************
* start with all zipcodes in ABC data
use "`zipcirc'", clear
keep zipcode stcntyfp pmsa market
ren zipcode temp
gen zipcode = string(temp,"%05.0f")
drop temp
duplicates drop

* merge in zip demo data
sort zipcode
merge zipcode using "`zipdemos'"
drop if _merge==2
gen nozipdemos = _merge==1
drop _merge
drop  geo_id-lon

* merge in zip contribution data
ren zipcode indivzip
sort indivzip
merge indivzip using "`zipcontrib'"
ren indivzip zipcode
drop if _merge==2
gen nocontributions = _merge==1
drop _merge
drop  rep_amt dem_amt rep_amt_share

placevar zipcode stcntyfp  pmsa market pop00- density00 hshd00 rep_count dem_count rep_count_share no*
renvars stcntyfp-density00 hshd00, prefix(zip_)
sort zipcode
save "`tempzip'", replace
duplicates report zipcode

**********************************************************
* ASSEMBLE NEWSPAPER-LEVEL TEMP FILE
**********************************************************
* start with all papers in the E&P dailies file
use "`dailies'", clear
keep dindex papername city state stcntyfp dailycirc employees pgsdaily pricedaily

* merge in newspaper demos
sort dindex
merge dindex using "`npdemos'" 
keep dindex-density00
mmerge npmarket using "../external/leip_npmarket.dta", unmatched(master) type(n:1)
placevar pctrep_2004, before(pop00)
drop _merge

* merge in biasmeasures
sort dindex
merge dindex using "`biasmeas'"
gen nobiasdata = `MEASURE'==.
drop _merge
keep dindex papername npmarket nobiasdata city state pctrep_2004-density00 multicity compcity pred_* totcount_*
placevar dindex papername npmarket nobiasdata city state npmarket pctrep_2004-density00 multicity compcity pred_* totcount_*

renvars city state pctrep_2004-density00 multicity compcity, prefix(np_)
ren npmarket np_market
sort dindex
save "`tempnp'", replace
duplicates report dindex

**********************************************************
* ASSEMBLE ZIP-NEWSPAPER LEVEL FILES
**********************************************************

* start with ABC circulation data
use "`zipcirc'", clear
ren zipcode temp
gen zipcode = string(temp,"%05.0f")
drop temp
keep abcid zipcode hshd dailycirc zipdailycirc market
ren market zip_market
ren hshd zip_hshd
ren zipdailycirc zip_dailycirc
drop if dailycirc==.

* merge in dindex
sort abcid
merge abcid using  "`npids'"
drop if _merge==2 | _merge==1 /* drop abcids w/ no dindex */
drop if dindex == .
drop _merge
drop titleID1-abcstate
collapse (sum) dailycirc (mean) zip_hshd, by (zip_dailycirc zip_market zipcode dindex)
replace zip_hshd = round(zip_hshd)

* merge in zipcode data
sort zipcode
merge zipcode using "`tempzip'"
tab _merge
drop if _merge==2
drop _merge

* merge in newspaper data
sort dindex
merge dindex using "`tempnp'"
tab _merge
drop if _merge==2
drop _merge

**********************************************************
* CLEAN UP AND SAVE
**********************************************************
drop if dailycirc==.
drop if dailycirc>zip_hshd /* note that this will make number of zips in markets unbalanced */

gen dailyshare = dailycirc/zip_hshd
gen logit = log(dailyshare)-log(1-dailyshare)

ren rep_count_share rep
ren `MEASURE' slant
gen rep2 = rep^2
gen slant2 = slant^2
gen pctrep2 = np_pctrep_2004^2
gen rep_pctrep = rep*np_pctrep_2004
gen rep_slant = rep*slant

gen zip_market_dindex = zip_market + "_" + string(dindex)
egen nzip_market_dindex = group(zip_market_dindex)

gen zip_colfrac00 = zip_pctcol00 + zip_pctgrad00
gen zip_lincpc = zip_linc00 - zip_lpop00

gen np_lincpc = log(np_incpc00)
gen np_lpop00 = log(np_pop00)
ren np_pctcol00 np_colfrac00
ren np_ownocc00 np_pctowneroc00

gen pop_pop = zip_lpop00*np_lpop00
gen inc_inc = zip_lincpc*np_lincpc
gen urban_urban = zip_pcturban00*np_pcturban00
gen white_white =  zip_pctwhite00*np_pctwhite00
gen black_black = zip_pctblack00*np_pctblack00
gen col_col =  zip_colfrac00* np_colfrac00
gen own_own = zip_pctowneroc00*np_pctowneroc00
gen dens_dens = zip_density00*np_density00

save "`output'", replace

* create zipcode quartiles / deciles
collapse (mean) rep rep_count, by(zipcode)
sort rep zipcode
gen index = _n
replace index = . if rep==.
egen zipquart = cut(index), g(4)
egen zipdec = cut(index), g(10)
tab zipquart
tab zipdec
drop rep index
sort zipcode
save "`temp'", replace
use "`output'", clear
sort zipcode
merge zipcode using "`temp'"
drop _merge
save "`output'", replace

* create slant quartiles / deciles
collapse (mean) slant, by(dindex)
egen npquart = cut(slant), g(4)
egen npdec = cut(slant), g(10)
drop slant
sort dindex
save "`temp'", replace
use "`output'", clear
sort dindex
merge dindex using "`temp'"
drop _merge
save "`output'", replace

* create np_pctrep_2004 quartiles / deciles
collapse (mean) np_pctrep_2004, by(dindex)
egen nprquart = cut(np_pctrep_2004), g(4)
egen nprdec = cut(np_pctrep_2004), g(10)
drop np_pctrep_2004
sort dindex
save "`temp'", replace
use "`output'", clear
sort dindex
merge dindex using "`temp'"
drop _merge
save "`output'", replace

placevar dindex zipcode zip_market papername dailycirc dailyshare logit rep rep2 slant slant2 rep_slant np_pctrep_2004 pctrep2 rep_pctrep rep_count /*
*/	 dem_count pred_* totcount_* np_* zip_* no* zip_market_dindex nzip_market_dindex zipquart /*
*/	 zipdec npquart npdec nprquart nprdec

sort zipcode dindex
compress
save "`output'", replace

drop nobiasdata
save "`outputabc'", replace

use "`output'", clear
drop if nobiasdata == 1
drop nobiasdata
save "`output'", replace
