**********************************************************
*
* SEARCHES_BUILD.DO: Combines search output from NewsLibrary and.
* ProQuest news databases and produces a single file of news counts.
*
**********************************************************

set more off
local doc "..\external"
local language "..\external\language_by_dindex.dta"
tempfile words pqdata nldata bothdata temp search phrasestemp

cap log close
clear
set mem 200m

** Change year here **
foreach year in 2005{
	log using "..\output\searches_build`year'.log", replace


** CREATE LIST OF UNIQUE STEMS **

	clear
	use "..\external\2005_Wordlist.dta"
	keep phrase
	duplicates drop
	sort phrase
	save `words', replace

** PREPARE PQ DATA **
	
	clear
	insheet using "`doc'\pq`year'.txt"
	capture keep if year==`year'
	rename hits pq_count
	rename stem phrase
	rename docid dindex
	sort dindex
	merge dindex using "`language'"
	tab _merge
	drop if _merge==2
	drop _merge
	keep if language=="E"
	drop language
	keep dindex phrase pq_count
	sort phrase
	merge phrase using `words'
	tab _merge
	list phrase if _merge==2
	drop if _merge==1&`year'~=2004
	drop if _merge==2&`year'==2004
	drop _merge
	fillin phrase dindex
	tab _fillin
	drop _fillin
	drop if dindex==.
	replace pq_count = 0 if pq_count==.
	egen totcount = sum(pq_count), by(dindex)
	tab dindex if totcount == 0
	egen totphr = sum(pq_count), by (phrase)
	tab phrase if totphr == 0
	drop totphr
	keep if totcount>100
	drop totcount
	sort dindex phrase
	save `pqdata', replace

** PREPARE NL DATA **
	
	clear
	insheet using "`doc'\nl`year'.txt"
	** hmmm the input tends to change format from year to year...
	if `year' == 2005 {
		ren state Code
		ren paper count
		drop nlcode coutn
		drop dindex
	}
	else {
		ren nlcode Code
		drop dindex
	}
	sort Code
	unique Code
	merge Code using "`doc'\nl_keep`year'"
	unique Code if _m == 3
	tab _merge
	keep if _merge == 3
	drop _merge
	sort dindex
	merge dindex using "`language'"
** Special for the AP
	replace language = "E" if Code == "APAB"

	tab _merge
	drop if _merge==2
	drop _merge
	keep if language=="E"
	drop language
	rename stem phrase
	rename count nl_count
	sort phrase
	merge phrase using `words'
	tab _merge
	list phrase if _merge==2
	drop if _merge==1&`year'~=2004
	drop if _merge==2&`year'==2004
	drop _merge
	egen totcount = sum(nl_count), by(dindex)
	keep if totcount>100
	drop totcount
	collapse (sum) nl_count, by(dindex phrase)
	fillin dindex phrase
	tab _fillin
	drop _fillin
	egen totphr = sum(nl_count), by (phrase)
	tab phrase if totphr == 0
	drop totphr
	drop if dindex==.
	replace nl_count = 0 if nl_count==.
	sort dindex phrase
	save `nldata', replace

** MERGE PQ DATA TO NL DATA **
** USE NL DATA IF NL DATA NONMISSING **
** IF NL DATA MISSING, USE PQ DATA **
	
	merge dindex phrase using `pqdata'
	tab _merge
	drop _merge

** ANALYSIS OF CONCORDANCE BETWEEN PQ AND NL

	egen pq_total = sum(pq_count), by(dindex)
	gen pq_share = pq_count/pq_total
	egen nl_total = sum(nl_count), by(dindex)
	gen nl_share = nl_count/nl_total

	display "ANALYSIS OF CONCORDANCE BETWEEN PQ AND NL"
	display "YEAR IS `year'"
	display "correlation of counts between PQ and NL"
	pwcorr pq_count nl_count, sig
	display "correlation of shares between PQ and NL"
	pwcorr pq_share nl_share, sig

	drop pq_total pq_share nl_total nl_share

	display "count of papers in both PQ and NL"
	codebook dindex if pq_count~=.&nl_count~=.
	display "count of all papers in NL"
	codebook dindex if nl_count~=.
	gen newslibrary = (nl_count!=.)
	display "count of all papers in PQ"
	codebook dindex if pq_count~=.
	gen proquest = (pq_count!=.)

	save `bothdata', replace
	gen hitcount = nl_count
	replace hitcount = pq_count if hitcount==.
	drop nl_count pq_count

** SAVE FINAL FILE FOR USE IN BUILDING BIAS MEASURES **
	
	keep dindex phrase hitcount newslibrary proquest
	sort dindex phrase
	save `temp'
	keep dindex newslibrary proquest
	duplicates drop
	save "..\output\db`year'.dta", replace
	use `temp', clear
	drop newslibrary proquest
	sort dindex phrase
	save "`search'", replace

** BUILD NEWSCOUNT DATA **

	use "`doc'\\`year'_Wordlist.dta", clear
	keep phrase
	sort phrase
	save "`phrasestemp'", replace

	use "`search'", clear

	* deal with multiple papers within dindex/phrase (i.e. suburban editions)
	collapse (sum) hitcount, by(dindex phrase)

	* merge in wordlist data
	sort phrase
	merge phrase using "`phrasestemp'"
	drop if _merge==2 | _merge==1
	drop _merge

	keep dindex phrase hitcount
	sort dindex
	compress
	save "..\output\\`year'_NewsCounts.dta", replace

	log close
}


