**********************************************************
*
* SPEAKERS_BUILD.DO: Build file with info on each speaker.
*
**********************************************************

**********************************************************
* PRELIMINARIES
**********************************************************
cap log close
clear
set mem 500m
set matsize 500
set more off

**********************************************************
* LOAD DATA AND PREPARE FOR MERGE
**********************************************************

tempfile speakerid house senate commonspace

* LOAD SPEAKER IDS AND ADA SCORES *
insheet using "..\external\109SpeakerID.txt", delim("|") clear
ren id speaker_id
replace party = "D" if party=="Democratic"
replace party = "R" if party=="Republican"
replace party = "I" if party=="Independent"
cap replace district = "99" if district=="At Large"
cap destring district, replace
drop if party=="N/A"
drop nom_ada
save "`speakerid'", replace

* LOAD DISTRICT REPSHARE FOR HOUSE
use "..\external\districtshare.dta" if year==2004, clear
keep state district repshare
save "`house'", replace

* LOAD STATE REPSHARE FOR SENATE
use "..\external\leip_state" if year==2004, clear
gen repshare_state =  voterep_p/(voterep_p+votedem_p)
mmerge st using "../external/state.dta", unmatched(master) ukeep(state) type(1:1)
drop if state=="DC"
keep state repshare_state
save "`senate'", replace

* LOAD COMMON SPACE SCORE
use "..\external\common_space_scores.dta", clear
rename idno icpsrid
keep if congress==109
keep icpsrid cs1
duplicates drop /* one case of someone who moves across chambers */
save "`commonspace'", replace

insheet using "..\external\MappingSpeakerID_ICPSRID.txt", delim("|") clear
keep if congress==109
keep speakerid icpsrid
rename speakerid speaker_id
keep speaker_id icpsrid
mmerge icpsrid using "`commonspace'", unmatched(master) ukeep(cs1) type(n:1)
destring speaker_id, replace
keep speaker_id cs1
save "`commonspace'", replace

**********************************************************
* MERGE AND SAVE
**********************************************************

* MERGE DATA
use "`speakerid'", clear
mmerge state district using "`house'", ukeep(repshare) unmatched(master) type(n:1)
mmerge state using "`senate'", ukeep(repshare_state) unmatched(master) type(n:1)
mmerge speaker_id using "`commonspace'", ukeep(cs1) unmatched(master) type(1:1)

* CREATE DESIRED VARIABLES
gen repshare_109 = repshare if chamber=="H"
replace repshare_109 = repshare_state if chamber=="S"
drop if repshare_109==.
drop repshare repshare_state
drop _merge

compress
save "..\temp\Speakers.dta", replace
