/**********************************************************
 *
 * ABCZIP_BUILD.DO
 *
 * Creator:		Matthew Gentzkow, edited by Nathan Petek for consistency with SVN repository organization
 * Date:		May, 2006
 *
 **********************************************************/

**********************************************************
* FILES
**********************************************************
local input1  "..\external\newspaper_zip_01to27.txt"
local input2  "..\external\newspaper_zip_28to61.txt"
local input3  "..\external\newspaper_zip_62to99.txt"

local output "..\temp\npzipcirc.dta"

local temp "..\temp\temp.dta"
local tempraw "..\temp\tempraw.dta"


**********************************************************
* PRELIMINARIES
**********************************************************
clear
set memory 600m
set matsize  500

**********************************************************
* ASSEMBLE FILES
**********************************************************
insheet using  "`input3'", clear
save "`temp'", replace

insheet using  "`input2'", clear
append using "`temp'"
save "`temp'", replace

insheet using "`input1'", clear
append using "`temp'"

**********************************************************
* CLEAN UP
**********************************************************
keep  membernumber newspaper city state zipcode ziptown zipstate hshd frequency hometot scstot grosstot avgpaidcirc
ren membernumber abcid

foreach V of varlist hshd hometot scstot grosstot avgpaidcirc {
	replace `V' = subinstr(`V',",","",.)
	destring `V', replace
}

foreach circ in hometot scstot grosstot avgpaidcirc {
	gen `circ'_d = `circ' if strpos(frequency,"SUN")==0 & strpos(frequency,"SAT")==0
	gen `circ'_sat = `circ' if strpos(frequency,"SAT")!=0
	gen `circ'_sun = `circ' if strpos(frequency,"SUN")!=0
}

collapse (max) hometot_d-avgpaidcirc_sun, by(abcid newspaper city state zipcode ziptown zipstate hshd)

ren avgpaidcirc_d dailycirc
ren avgpaidcirc_sat satcirc
ren avgpaidcirc_sun suncirc

egen zipdailycirc = sum(dailycirc), by(zipcode)
gen share = dailycirc/zipdailycirc
gen share2 = share^2
egen hhi = sum(share2), by(zipcode)
replace hhi = hhi*10000
drop share share2

sort abcid zipcode
save "`output'", replace

erase "`temp'"
