 **********************************************************
 *
 * NPZIPCIRCZEROES_BUILD.DO
 *
 * Edited by Nathan Petek for consistency with SVN repository
 * Date: September, 2006
 *
 **********************************************************

**********************************************************
* FILENAMES
**********************************************************
local outdir "..\output"

local zipfile "..\external\zips_wide"
local npcirc "..\temp\npzipcirc.dta"
local counties "..\external\counties"
local hshdfill "..\external\npziphshdfill_mkt"

*temp files
tempfile idcntypairs
tempfile zips
tempfile pairwise
tempfile zipcode
tempfile temp
tempfile ziphshd
tempfile pmsa
tempfile zipcntypmsa

**********************************************************
* PRELIMINARIES
**********************************************************
cap log close
clear
set mem 700m
set matsize 500
set maxvar 20000
set more off

**********************************************************
* PREPARE TEMP DATASETS FOR MERGES
**********************************************************
 
* ZIPCODE just relates stcntyfp to a zipcode
use "`zipfile'"

* county code for Miami has changed since 1990
* when counties file was built
replace stcntyfp="12025" if stcntyfp=="12086"

sort stcntyfp
merge stcntyfp using "`counties'", keep(pmsa)
drop if _merge == 2
drop _merge
keep zipcode stcntyfp pmsa
drop if stcntyfp == ".."
save "`zipcode'", replace
sort zipcode 
save "`zipcntypmsa'"

drop if pmsa == ""
drop stcntyfp
duplicates drop
sort pmsa
save "`pmsa'"
use "`zipcode'"

sort zipcode stcntyfp
save "`zipcode'", replace
clear

use "`npcirc'"

sort zipcode
* Merge in to add the stcntyfp (county) field
merge zipcode using "`zipcode'"
drop if _merge == 2
drop _merge
save "`temp'"

keep abcid stcntyfp newspaper city state pmsa
gen market = pmsa 
replace market = stcntyfp if pmsa == ""
drop if market == ""
drop stcntyfp pmsa
duplicates drop

** IDCNTYPAIRS is all possible pairs of abcids and stcntyfps
save "`idcntypairs'", replace

use "`temp'"
keep zipcode hshd
duplicates drop
sort zipcode
** ZIPHSHD is the hshd reading for each zip code
save "`ziphshd'"

** RE-SORT ZIPCODE another way for its next merge
use "`zipcode'"
drop pmsa
sort stcntyfp zipcode
save "`zipcode'", replace
clear

use "`idcntypairs'"

rename market stcntyfp
sort stcntyfp

** JOINBY WILL DO THE FILLIN THAT WE NEED
** First joinby county (county is blank where pmsa exists)
joinby stcntyfp using "`zipcode'", unmatched(master)
ren _merge stcntyfp_merge

ren stcntyfp pmsa
sort pmsa
** Then, joinby pmsa
joinby pmsa using "`pmsa'", unmatched(master) update

ren pmsa market 

drop _merge
drop stcntyfp_merge


sort abcid market zipcode

** PAIRWISE IS ALL COMBOS OF abcids, markets AND zipcodes! 
save "`pairwise'", replace


**********************************************************
* PERFORM MERGES TO GROW DATASET
**********************************************************

use "`temp'"

gen market = pmsa
replace market = stcntyfp if pmsa == ""

sort abcid market zipcode

** THIS WILL ADD IN ALL PAIRWISE POSSIBILITIES THAT WE NEED
joinby abcid market zipcode using "`pairwise'", update unmatched(using)

* blank out the circulation
replace dailycirc= 0 if _merge == 2
replace satcirc= 0 if _merge == 2
replace suncirc= 0 if _merge == 2
drop _merge

* add back in the hshd field, where available
sort abcid zipcode
merge abcid zipcode using "`hshdfill'", update
* drop right-side merges
drop if _merge == 2
drop _merge


* carry over other zipcode-level variables to newly added obs
egen newhhi = max(hhi), by(zipcode)
replace hhi = newhhi
egen newzipdailycirc = max(zipdailycirc), by(zipcode)
replace zipdailycirc = newzipdailycirc
drop newhhi newzipdailycirc
gsort zipcode -ziptown
replace ziptown = ziptown[_n-1] if zipcode==zipcode[_n-1] & ziptown=="" & ziptown[_n-1]!=""
gsort zipcode -zipstate
replace zipstate = zipstate[_n-1] if zipcode==zipcode[_n-1] & zipstate=="" & zipstate[_n-1]!=""

* correct for extra fillins daily/sun/sat
egen max = max(dailycirc), by(market abcid)
replace dailycirc = . if max==0
drop max
egen max = max(satcirc), by(market abcid)
replace satcirc = . if max==0
drop max
egen max = max(suncirc), by(market abcid)
replace suncirc = . if max==0
drop max

* drop zipcodes that were not in ABC data to begin with
egen totcirc = rsum(dailycirc satcirc suncirc)
egen max = max(totcirc), by(zipcode)
drop if max==0
drop totcirc max


sort zipcode
merge zipcode using "`zipcntypmsa'", update
drop if _merge == 2
drop _merge

**********************************************************
* OUTPUT FILE
**********************************************************
compress
sort abcid zipcode
save "`outdir'\\npzipcirczeroes_mkt.dta", replace
