/**********************************************************
 *
 * EANDP_BUILD.DO: Build editor & publisher data files
 *
 * Creator:		Matthew Gentzkow. Edited by Yao Lu, July 2009 (for consistency with SVN organization).
 * Date:		March, 2006
 *
 **********************************************************/

**********************************************************
* DIRECTORIES USED
**********************************************************
local dir "..\external"
local dir2 "..\output"

**********************************************************
* INPUT FILES
**********************************************************
local zips "`dir'\zips_wide.dta"
local dailiestxt "`dir'\DAILIES.txt"
local labeldaily "labeldaily.do"
local weeklytxt "`dir'\WEEKLY.txt"
local labelweekly "labelweekly.do"
local foreigntxt "`dir'\FOREIGN.txt"
local labelforeign "labelforeign.do"
local groupstxt "`dir'\GROUPS.txt"
local labelgroups "labelgroups.do"
local adrepstxt "`dir'\ADREPS.txt"
local labeladreps "labeladreps.do"
local corresptxt "`dir'\CORRESP.txt"
local labelcorresp "labelcorresp.do"
local equiptxt "`dir'\EQUIP.txt"
local labelequip "labelequip.do"

**********************************************************
* TEMP FILES
**********************************************************
local temp "temp.dta"

**********************************************************
* OUTPUT FILES
**********************************************************
local dailies "`dir2'\dailies2001.dta"
local weeklies "`dir2'\weeklies2001.dta"
local foreign "`dir2'\foreign2001.dta"
local groups "`dir2'\groups2001.dta"
local adreps "`dir2'\adreps2001.dta"
local corresp "`dir2'\correspondents2001.dta"
local equip "`dir2'\equipcompanies2001.dta"

**********************************************************
* PRELIMINARIES
**********************************************************
capture log close
clear
set memory 600m
set matsize  500
set more off

**********************************************************
* DAILIES
**********************************************************
* build temporary file with merged geography
insheet using "`dailiestxt'", clear names
keep papertype-dcountry
ren news1paper newspaper
gen zipcode = real(substr(dzip,1,5))

replace zipcode = 20110 if zipcode==22110
replace zipcode = 35907 if zipcode==35999
replace zipcode = 75483 if zipcode==75843
replace zipcode = 81082 if zipcode==80182
replace zipcode = 30237 if zipcode==37237
replace zipcode = 97708 if zipcode==99708

sort zipcode
merge zipcode using "`zips'"
drop if _merge==2
drop _merge
keep newspaper frequency dzip zipcode stcntyfp county
sort newspaper frequency dzip
save "`temp'" , replace

* load dailies file and merge
insheet using  "`dailiestxt'" , clear names
do "`labeldaily'"
ren news1paper newspaper
sort dstate dcity newspaper
gen dindex = _n
placevar dindex
sort newspaper frequency dzip
merge newspaper frequency dzip using "`temp'"
drop _merge
placevar zipcode stcntyfp county, a(frequency)
label var county ""
save "`dailies'", replace

**********************************************************
* WEEKLIES
**********************************************************
insheet using  "`weeklytxt'", clear names
do "`labelweekly'"
sort wstate wcity wnewspaper
gen windex = _n
placevar windex
save "`weeklies'", replace

**********************************************************
* FOREIGN
**********************************************************
insheet using  "`foreigntxt'", clear names
do "`labelforeign'"
sort fcountry fnewspaper
gen findex = _n
placevar findex
save "`foreign'", replace

**********************************************************
* GROUPS
**********************************************************
* create aliases temp file


insheet using  "`groupstxt'", clear names
do "`labelgroups'"
sort ggroup
gen gindex = _n
placevar gindex
save "`groups'", replace


**********************************************************
* ADV REPS
**********************************************************
insheet using  "`adrepstxt'", clear names
do "`labeladreps'"
sort rrep
gen rindex = _n
placevar rindex
save "`adreps'", replace

**********************************************************
* FOREIGN CORRESPONDENTS 
**********************************************************
insheet using  "`corresptxt'", clear names
do "`labelcorresp'"
save "`corresp'", replace

**********************************************************
* EQUIPMENT
**********************************************************
insheet using  "`equiptxt'", clear names
do "`labelequip'"
save "`equip'", replace

erase "`temp'"
