/**********************************************************
 *
 * EANDPDAILY_CLEAN.DO: Clean daily file
 *
 * Creator:		Matthew Gentzkow. Edited by Yao Lu, July 2009 (for consistency with SVN organization).
 * Date:		March, 2006
 *
 **********************************************************/

**********************************************************
* DIRECTORIES USED
**********************************************************
local dir "..\external"
local dir2 "..\output"

**********************************************************
* INPUT FILES
**********************************************************
local dailies "`dir2'\dailies2001.dta"
local altcities "`dir'\alternatecities.dta"
local joa "`dir'\joa.dta"
local alias "`dir'\groupaliases.txt"
local toadd "`dir'\groupstoadd.txt"
local ownpanel "`dir'\ownership1995to2004.txt"
local groups "`dir2'\groups2001_clean.dta"
local language "`dir'\language_by_dindex.dta"
local label "label.do"

**********************************************************
* TEMP FILES
**********************************************************
local temp "temp.dta"
local aliastemp "aliastemp.dta"
local owntemp "owntemp.dta"

**********************************************************
* OUTPUT FILES
**********************************************************
local output "`dir2'\dailies2001_clean.dta"
local canada "`dir2'\dailies2001_canada.dta"
local changes "`dir2'\ownershipchanges.dta"

**********************************************************
* PRELIMINARIES
**********************************************************
clear
set memory 600m
set matsize  500

**********************************************************
* CREATE NEWS SERVICES TEMP FILE
**********************************************************
use "`dailies'",  clear
keep dindex newsserv

* corrections
replace newsserv = lower(news)
replace newsserv = subinstr(newsserv," ","",.)
replace newsserv = subinstr(newsserv,"-","",.)
replace newsserv = subinstr(newsserv,"(","",.)
replace newsserv = subinstr(newsserv,")","",.)
replace newsserv = subinstr(newsserv,",","",.)
replace newsserv = subinstr(newsserv,".","",.)

split newsserv, gen(news) parse(";")
reshape long news, i(dindex) j(servnum)
drop if news==""

* more corrections
replace news = "krt" if news=="knightriddertribune"
replace news = "cns" if news=="copley"
replace news = "cox" if news=="coxnewsservice"
replace news = "dj" if news=="dowjones"
replace news = "gns" if news=="gannett"
replace news = "latwp" if news=="lat"
replace news = "latwp" if news=="wp"
replace news = "latwp" if news=="washingtonpost"
replace news = "mcc" if news=="mcclatchy"
replace news = "shns" if news=="scrippshoward"
replace news = "shns" if news=="scrippshowardnewsdigest"
replace news = "bloom" if news=="bloombergbusinessnews"
replace news = "bloom" if news=="bloomberg"
replace news = "pr" if news=="prnewswire"

vallist news, local(newslist)
foreach SVC in `newslist' {
	quietly count if news=="`SVC'"
	local count = r(N)
	if `count'>10 {
		gen temp = news=="`SVC'"
		egen news_`SVC' = max(temp), by(dindex)
		drop temp
	}
}
collapse (mean) news_*, by(dindex)
sort dindex
save "`temp'", replace

**********************************************************
* CREATE OWNERSHIP PANEL TEMP FILE
**********************************************************
insheet using "`ownpanel'", clear
sort dindex
save "`owntemp'", replace

**********************************************************
* CREATE GROUP ALIASES TEMP FILE
**********************************************************
* save temp file
insheet using "`toadd'", clear
drop groupid endmonth endyear notes
save "`aliastemp'", replace

* load aliases
insheet using "`alias'", clear
drop if gindex==.
append using "`aliastemp'"
reshape long alias, i(gindex) j(aliasnum)
keep gindex alias
drop if alias==""
ren alias groupname
sort groupname
save "`aliastemp'", replace

**********************************************************
* LOAD FILE
**********************************************************
use "`dailies'",  clear
keep  dindex newspaper frequency zipcode stcntyfp county dcity dstate dcountry dzip morcircmf-combrate /*
	*/ aubpricew aubpricem aubpricey aubpriceo format politics newsserv year_est /*
	*/groupaffil employees pgsdaily pgssat pgssun newswire photowire stockwire syndwire receivdish

**********************************************************
* FREQUENCY
**********************************************************
gen freqtemp = frequency

* cleaning
drop if freqtemp==""
replace freqtemp = subinstr(freqtemp,":",";",.)
replace freqtemp = subinstr(freqtemp,"mon-fri","mon to fri",.)
replace freqtemp = subinstr(freqtemp,"thurs","thur",.)
replace freqtemp = subinstr(freqtemp,";sat","; m-sat",.)
replace freqtemp = subinstr(freqtemp,",",";",.) if dindex==1104 | dindex==1031 | dindex==1033
replace freqtemp = subinstr(freqtemp,"all day","a",.)

* parse Sunday
gen sunday = strpos(freqtemp,";S")!=0 | strpos(freqtemp,"; S")!=0 | strpos(freqtemp,";  S")!=0
replace freqtemp = subinstr(freqtemp,";S","",.)
replace freqtemp = subinstr(freqtemp,"; S","",.)
replace freqtemp = subinstr(freqtemp,";  S","",.)

* parse Saturday
gen saturday = strpos(freqtemp,"sat")!=0 | strpos(freqtemp,"wknd")!=0
gen saturdaytime = ""
replace saturdaytime = "m" if strpos(freqtemp,"m-sat")!=0 | strpos(freqtemp,"m-mon to sat")!=0 | strpos(freqtemp,"m-tues to sat")!=0 | strpos(freqtemp,"m-wed to sat")!=0 | strpos(freqtemp,"m-thur to sat")!=0 | strpos(freqtemp,"m-fri to sat")!=0 | strpos(freqtemp,"wknd")!=0
replace saturdaytime = "e" if strpos(freqtemp,"e-sat")!=0 | strpos(freqtemp,"e-mon to sat")!=0 | strpos(freqtemp,"e-tues to sat")!=0 | strpos(freqtemp,"e-wed to sat")!=0 | strpos(freqtemp,"e-thur to sat")!=0 | strpos(freqtemp,"e-fri to sat")!=0
replace saturdaytime = "a" if strpos(freqtemp,"all day-sat")!=0 | strpos(freqtemp,"all day-mon to sat")!=0 | strpos(freqtemp,"all day-tues to sat")!=0 | strpos(freqtemp,"all day-wed to sat")!=0 | strpos(freqtemp,"all day-thur to sat")!=0 | strpos(freqtemp,"all day-fri to sat")!=0
replace freqtemp = subinstr(freqtemp,";m-sat","",.)
replace freqtemp = subinstr(freqtemp,";e-sat","",.)
replace freqtemp = subinstr(freqtemp,"; m-sat","",.)
replace freqtemp = subinstr(freqtemp,"; e-sat","",.)
replace freqtemp = subinstr(freqtemp,"to sat","to fri",.)

* parse frequency variable (freqtemp) into separate fields by ";"
split freqtemp, gen(freq) parse(";")
foreach n of numlist 1/4 {
	split freq`n', gen(temp) parse("-")
	replace temp1 = trim(temp1)
	replace temp2 = trim(temp2)
	ren temp1 freqtime`n'
	ren temp2 freqdays`n'	
}

* create variables for each day
gen monday = 0
gen tuesday = 0
gen wednesday = 0
gen thursday = 0
gen friday = 0
gen mondaytimes = ""
gen tuesdaytimes = ""
gen wednesdaytimes = ""
gen thursdaytimes = ""
gen fridaytimes = ""
foreach n of numlist 1/4 {
	replace monday = monday + (strpos(freqdays`n',"mon") !=0 | strpos(freqdays`n',"mon to fri") !=0 | strpos(freqdays`n',"mon to thur") !=0 | strpos(freqdays`n',"mon to tues") !=0 | strpos(freqdays`n',"mon to wed") !=0   )        
	replace mondaytimes = mondaytimes + freqtime`n' if (strpos(freqdays`n',"mon") !=0 | strpos(freqdays`n',"mon to fri") !=0 | strpos(freqdays`n',"mon to thur") !=0 | strpos(freqdays`n',"mon to tues") !=0 | strpos(freqdays`n',"mon to wed") !=0   )        
	replace tuesday = tuesday + (strpos(freqdays`n',"mon to fri") !=0 | strpos(freqdays`n',"mon to thur") !=0 | strpos(freqdays`n',"mon to tues") !=0 | strpos(freqdays`n',"mon to wed") !=0 | strpos(freqdays`n',"tues") !=0 | strpos(freqdays`n',"tues to fri") !=0 | strpos(freqdays`n',"tues, wed, fri") !=0      | strpos(freqdays`n',"tues to thur") !=0 ) 
	replace tuesdaytimes = tuesdaytimes + freqtime`n' if (strpos(freqdays`n',"mon to fri") !=0 | strpos(freqdays`n',"mon to thur") !=0 | strpos(freqdays`n',"mon to tues") !=0 | strpos(freqdays`n',"mon to wed") !=0 | strpos(freqdays`n',"tues") !=0 | strpos(freqdays`n',"tues to fri") !=0 | strpos(freqdays`n',"tues, wed, fri") !=0      | strpos(freqdays`n',"tues to thur") !=0 ) 
	replace wednesday = wednesday + (strpos(freqdays`n',"mon to fri") !=0 | strpos(freqdays`n',"mon to thur") !=0  | strpos(freqdays`n',"mon to wed") !=0  | strpos(freqdays`n',"tues to fri") !=0 | strpos(freqdays`n',"tues, wed, fri") !=0 | strpos(freqdays`n',"wed to fri") !=0     | strpos(freqdays`n',"tues to thur") !=0 | strpos(freqdays`n',"wed") !=0 )
	replace wednesdaytimes = wednesdaytimes + freqtime`n' if (strpos(freqdays`n',"mon to fri") !=0 | strpos(freqdays`n',"mon to thur") !=0  | strpos(freqdays`n',"mon to wed") !=0  | strpos(freqdays`n',"tues to fri") !=0 | strpos(freqdays`n',"tues, wed, fri") !=0 | strpos(freqdays`n',"wed to fri") !=0     | strpos(freqdays`n',"tues to thur") !=0 | strpos(freqdays`n',"wed") !=0 )
	replace thursday = thursday + (strpos(freqdays`n',"mon to fri") !=0 | strpos(freqdays`n',"mon to thur") !=0    | strpos(freqdays`n',"tues to fri") !=0  | strpos(freqdays`n',"wed to fri") !=0   | strpos(freqdays`n',"thur") !=0 | strpos(freqdays`n',"thur to fri") !=0 | strpos(freqdays`n',"tues to thur") !=0  )
	replace thursdaytimes = thursdaytimes + freqtime`n' if (strpos(freqdays`n',"mon to fri") !=0 | strpos(freqdays`n',"mon to thur") !=0    | strpos(freqdays`n',"tues to fri") !=0  | strpos(freqdays`n',"wed to fri") !=0   | strpos(freqdays`n',"thur") !=0 | strpos(freqdays`n',"thur to fri") !=0 | strpos(freqdays`n',"tues to thur") !=0  )
	replace friday  = friday + (strpos(freqdays`n',"mon to fri") !=0     | strpos(freqdays`n',"tues to fri") !=0 | strpos(freqdays`n',"tues, wed, fri") !=0 | strpos(freqdays`n',"wed to fri") !=0 | strpos(freqdays`n',"fri") !=0 | strpos(freqdays`n',"fri to fri") !=0  | strpos(freqdays`n',"thur to fri") !=0  )
	replace fridaytimes  = fridaytimes + freqtime`n' if (strpos(freqdays`n',"mon to fri") !=0     | strpos(freqdays`n',"tues to fri") !=0 | strpos(freqdays`n',"tues, wed, fri") !=0 | strpos(freqdays`n',"wed to fri") !=0 | strpos(freqdays`n',"fri") !=0 | strpos(freqdays`n',"fri to fri") !=0  | strpos(freqdays`n',"thur to fri") !=0  )
}

replace monday = monday!=0
replace tuesday = tuesday!=0
replace wednesday = wednesday!=0
replace thursday = thursday!=0
replace friday = friday!=0

* create the variables to actually keep
gen timeofday = mondaytimes
replace timeofday = tuesdaytimes if timeofday==""
replace timeofday = wednesdaytimes if timeofday==""
replace timeofday = thursdaytimes if timeofday==""
replace timeofday = fridaytimes if timeofday==""
replace timeofday = "various" if timeofday!=tuesdaytimes&tuesdaytimes!="" | timeofday!=wednesdaytimes&wednesdaytimes!="" | timeofday!=thursdaytimes&thursdaytimes!="" | timeofday!=fridaytimes&fridaytimes!=""

gen numdays = (monday!=0) + (tuesday!=0) + (wednesday!=0) + (thursday!=0) + (friday!=0) + (saturday!=0) + (sunday!=0)
gen numweekdays = (monday!=0) + (tuesday!=0) + (wednesday!=0) + (thursday!=0) + (friday!=0)

**********************************************************
* NEWSPAPER NAMES
**********************************************************
split newspaper, gen(name) parse(";")
gen papername = name1

* sundayname
gen sundayname = name3 if sunday==1
replace name3="" if name3==sundayname
replace sundayname = name2 if sundayname=="" & sunday==1
replace name2="" if name2==sundayname

* saturdayname
gen saturdayname = name3 if saturday==1 & sunday==0 & substr(frequency,-5,.)=="m-sat"
replace name3="" if name3==saturdayname
replace saturdayname = name2 if saturdayname=="" & saturday==1 & sunday==0 & substr(frequency,-5,.)=="m-sat"
replace saturdayname = name2 if strpos(name2,"Saturday")!=0
replace name2="" if name2==saturdayname

* evening name
gen eveningname = name2 if timeofday=="me" | timeofday=="various"

**********************************************************
* CIRCULATION
**********************************************************
replace morcircmf = subinstr(morcircmf,",","",.)
replace evecircmf = subinstr(evecircmf ,",","",.)
replace acircmf = subinstr(acircmf,",","",.)
replace morcircsat = subinstr(morcircsat ,",","",.)
replace evecircsat = subinstr(evecircsat ,",","",.)
replace circsun = subinstr(circsun ,",","",.)

destring morcircmf evecircmf acircmf morcircsat evecircsat circsun, replace
mvencode morcircmf evecircmf acircmf morcircsat evecircsat circsun, mv(0)

gen dailycirc = morcircmf + evecircmf + acircmf
gen satcirc = morcircsat + evecircsat
ren circsun suncirc

**********************************************************
* AD PRICES
**********************************************************
replace ratesun = subinstr(ratesun,",",".",.)
destring ratesun, replace
egen dailyadrate = rmax(morratemf everatemf aratemf)
egen satadrate = rmax(morratesat everatesat)
ren ratesun sunadrate

**********************************************************
* COVER PRICES
**********************************************************
replace pricemf=".25" if dindex==181 | dindex==286
replace pricesat=".25" if dindex==181 | dindex==286
replace pricesun="1.25" if dindex==181
replace pricesun=".75" if dindex==286
replace pricemf = "0" if pricemf=="Free"
replace pricesat = "0" if pricesat=="Free"
replace pricesun = "0" if pricesun=="Free"
destring pricemf pricesat pricesun, replace

**********************************************************
* EMPLOYEES
**********************************************************
replace employees = subinstr(employees,",","",.)
replace employees = "87" if dindex==834
replace employees = "400" if dindex==606
replace employees = "177" if dindex==1072
replace employees = "45" if dindex==322
replace employees = "" if dindex==993
destring employees, replace

**********************************************************
* PAGES
**********************************************************
replace pgsdaily = "13" if dindex==362
replace pgsdaily = "24.3" if dindex==562
replace pgsdaily = "15.5" if dindex==366
destring pgsdaily, replace

replace pgssat = "37.5" if dindex==110
replace pgssat = "33.25" if dindex==562
replace pgssat = "32" if dindex==178
replace pgssat = "" if dindex==1067
destring pgssat, replace

**********************************************************
* NEWS SERVICES
**********************************************************
sort dindex
merge dindex using "`temp'"
drop if _merge==2
drop _merge

**********************************************************
* ALTERNATE CITY NAMES
**********************************************************
merge dindex using "`altcities'", sort
drop city state
drop _merge
gen city_orig = dcity
replace dcity = alternatecity if alternatecity!=""

**********************************************************
* JOAs
**********************************************************
merge dindex using "`joa'", sort
drop city state
drop _merge

**********************************************************
* GROUP IDS
**********************************************************
ren groupaffil groupname

* fix some errors in E&P data for groups
replace groupname = "Dow Jones & Company (Ottaway Newspapers Inc.)" if dindex==174
replace groupname = "Black Press Ltd" if dindex==324
replace groupname = "Wehco Media Inc." if dindex==1339

sort groupname
merge groupname using "`aliastemp'"
drop if _merge==2
drop _merge

**********************************************************
* OWNERSHIP PANEL DATA
**********************************************************
sort dindex
merge dindex using "`owntemp'"
drop _merge
egen temp = rownonmiss(gindex1995-gindex2004)
gen nopaneldata = temp==0
drop temp

**********************************************************
* TAG MULTI-PAPER CITIES
**********************************************************
sort dstate dcity gindex
gen temp = dstate==dstate[_n-1] & dcity==dcity[_n-1] & (gindex!=gindex[_n-1] | gindex==.)
egen multicity = sum(temp), by(dstate dcity)
drop temp
replace multicity = multicity!=0
gen temp = multicity & joa==.
egen compcity = max(temp), by(dstate dcity)
replace compcity=0 if dcity=="Oil City" /* no group listed but E&P says they're jointly owned */
drop temp

**********************************************************
* MERGE IN LANGUAGE INFO
**********************************************************
sort dindex
merge dindex using "`language'"
drop if _merge==2
drop _merge

**********************************************************
* CLEAN UP AND LABEL
**********************************************************
ren newspaper name_orig
ren frequency frequency_orig
ren newsserv newsserv_orig
ren dcity city
ren dstate state
ren dcountry country
ren pricemf pricedaily

placevar  dindex papername city state county zipcode country alternatecity stcntyfp language multicity compcity joa groupname gindex nopaneldata gindex1995-gindex2004 eveningname saturdayname /*
*/ sundayname  dailycirc satcirc suncirc timeofday numdays numweekdays monday tuesday wednesday thursday /*
*/ friday saturday sunday format politics year_est employees pgsdaily pgssat pgssun pricedaily pricesat priceoth /*
*/ pricesun dailyadrate satadrate sunadrate news_* frequency_orig newsserv_orig name_orig 
keep dindex-name_orig

do "`label'"

foreach V of varlist gindex* {
	replace `V' = . if `V' == 0
}

**********************************************************
* SAVE US FILE
**********************************************************
save "`temp'", replace
keep if country=="US"
drop country
sort dindex
save "`output'", replace

**********************************************************
* SAVE CANADA FILE
**********************************************************
use "`temp'", clear
keep if country=="CANADA"
sort dindex
save "`canada'", replace

**********************************************************
* SAVE CHANGES FILE
**********************************************************
use "`output'", clear
drop if nopaneldata==1
keep dindex papername city state gindex*
drop gindex
reshape long gindex, i(dindex) j(year)
sort gindex
merge gindex using "`groups'" 
drop if _merge==2
drop _merge
drop alias* gcity gstate gzip gcountry
sort dindex year
gen gindex_next = gindex[_n+1] if dindex==dindex[_n+1]
gen groupname_next = groupname[_n+1] if dindex==dindex[_n+1]
drop if year==2004
keep if gindex!=gindex_next
replace groupname="" if groupname=="Western Massachusetts Newspapers" | groupname=="Worrell Enterprises Inc" /*This line added by YL so that repo version of ownershipchanges.dta matches "\\gsball-b\gslabshare\DATA\Newspapers\Editor & Publisher 2001\ownershipchanges.dta"*/
label var year "Year"
label var gindex "Group ID This Year"
label var groupname "Group Name This Year"
label var gindex_next "Group ID Next Year"
label var groupname_next "Group Name Next Year"
save "`changes'", replace

erase "`temp'"
erase "`aliastemp'"
erase "`owntemp'"
