/**********************************************************
 *
 * LEIP_PRES_STATE: Merge and clean the presidential election by state files.
 *		  	
 *
 * Creators:	Rui Silva and Margarida Soares. Edited by Nathan Petek (for consistency with SVN organization)
 * Date:		July, 2009
 *
 **********************************************************/


**********************************************************
* PRELIMINARIES
**********************************************************
clear
set memory 100m
set more off


**********************************************************
* DIRECTORIES USED
**********************************************************
local dir "..\external"
local dir3 "..\output"


**********************************************************
* OUTPUT FILE
**********************************************************
local presstate "`dir3'\leip_state"

**********************************************************
* Load the Presidential data from David Leip
**********************************************************
clear
insheet using "`dir'\Leip2004P.csv"

**********************************************************
* Merge on State FIPS Codes & DROP VARIABLES AT THE FIPS LEVEL
**********************************************************
sort state
merge state using "`dir'\state"
tab _merge
drop state name statece-_merge
sort year st


**********************************************************
* REPLACE MISSINGS WITH ZEROS, RENAME VARIABLES, ADD DATA LABELS
**********************************************************

rename totvotes_p votetot_p
rename demvotes_p votedem_p
rename demname_p namedem_p
rename repvotes_p voterep_p 
rename repname_p namerep_p
rename thirdvotes_p votethirdparty_p
rename thirdparty_p thirdparty_partyname_p
rename thirdname_p namethirdparty_p

do "..\code\label\labels_leip_state.do"

**********************************************************
* SAVE OUTPUT
**********************************************************
placevar year st
sort year st
unique year st
compress
sum
desc

save "`presstate'", replace
